"""
CircuitPython Program for RGB LED Control on ESP32-C3 Supermini
===============================================================
This program controls a common anode RGB LED connected to the ESP32-C3.
The `rainbowio` library is used to generate a color wheel effect on the LED.

Hardware Setup:
- Red LED cathode connected to IO1
- Green LED cathode connected to IO2
- Blue LED cathode connected to IO3
- Common anode connected to 3.3V
- Current-limiting resistors (220-510 ohms) for each LED
"""

import time
import board
import pwmio
from rainbowio import colorwheel

# Create PWM objects for each LED color
red = pwmio.PWMOut(board.IO1, frequency=1000)
green = pwmio.PWMOut(board.IO2, frequency=1000)
blue = pwmio.PWMOut(board.IO3, frequency=1000)

def set_rgb_color(r, g, b):
    # For common anode, we invert the duty cycle
    red.duty_cycle = 65535 - (r * 257)
    green.duty_cycle = 65535 - (g * 257)
    blue.duty_cycle = 65535 - (b * 257)

while True:
    for i in range(256):
        color = colorwheel(i)
        r = (color >> 16) & 0xFF
        g = (color >> 8) & 0xFF
        b = color & 0xFF
        set_rgb_color(r, g, b)
        time.sleep(0.05)
