# boci-boci.py
#
# This program plays the melody "Boci-boci tarka" using the piezo buzzer connected to IO4.
# The melody is stored in an array with note names and durations in 1/16th note units.
# The tempo is set to 72 BPM.
# 
# Hardware Requirements:
# - ESP32-C3 Supermini
# - Piezo buzzer connected to IO4
#
# Tested with CircuitPython v9.2.1

import pwmio
import board
import time

# Initialize PWM output on IO4 for the piezo buzzer
pwm = pwmio.PWMOut(board.IO4, duty_cycle=2**15, frequency=440, variable_frequency=True)

NOTE_FREQUENCIES = {
    "C": 261.63,  # C4
    "D": 293.66,  # D4
    "E": 329.63,  # E4
    "F": 349.23,  # F4
    "G": 392.00,  # G4
    "A": 440.00,  # A4
    "H": 493.88,  # H4
    "c": 523.25   # C5
}


# Melody and durations (1/16 note units)
melody = [
    ("C", 2), ("E", 2), ("C", 2), ("E", 2),("G", 4), ("G", 4), 
    ("C", 2), ("E", 2), ("C", 2), ("E", 2),("G", 4), ("G", 4), 
    ("c", 2), ("H", 2), ("A", 2), ("G", 2),("F", 4), ("A", 4), 
    ("G", 2), ("F", 2), ("E", 2), ("D", 2),("C", 4), ("C", 4)      
]

# Tempo (BPM)
tempo = 72
beat_duration = 60 / tempo / 4  # Duration of a 1/16 note

# Play the melody
for note, duration in melody:
    frequency = NOTE_FREQUENCIES[note]
    pwm.frequency = int(frequency)
    pwm.duty_cycle = 2**15  # 50% duty cycle
    time.sleep(beat_duration * duration)
    pwm.duty_cycle = 0  # Turn off the buzzer between notes
    time.sleep(beat_duration * 0.1)  # Short pause between notes
