"""
CircuitPython Program for Servo Motor Control on ESP32-C3 Supermini
==================================================================
This program controls a servo motor connected to IO0 using PWM signals.
The servo motor moves between 0 and 180 degrees.

The `angle_to_duty_cycle` function converts the desired angle (0-180) to
the corresponding duty cycle for PWM control. The main loop moves the
servo back and forth between 0 and 180 degrees in 10-degree steps.

Hardware Setup:
- Servo motor signal wire connected to IO0
- Servo motor power wire connected to 5V
- Servo motor ground wire connected to GND
"""

import time
import board
import pwmio

# Create a PWMOut object on pin IO0
pwm = pwmio.PWMOut(board.IO0, frequency=50)

# Function to convert angle to duty cycle
def angle_to_duty_cycle(angle):
    # Convert angle (0-180) to pulse width (0.5-2.5 ms)
    pulse_width_ms = 0.5 + (2.0 * angle / 180)
    # Convert pulse width to duty cycle (0-65535)
    duty_cycle = int((pulse_width_ms / 20) * 65535)
    return duty_cycle

while True:
    for angle in range(0, 181, 10):  # Move servo from 0 to 180 degrees
        pwm.duty_cycle = angle_to_duty_cycle(angle)
        time.sleep(1)
    for angle in range(180, -1, -10):  # Move servo from 180 to 0 degrees
        pwm.duty_cycle = angle_to_duty_cycle(angle)
        time.sleep(1)
